finetuneas, an HTML interface for fine tuning aeneas sync maps

finetuneas

1. Before you start making adjustments, check several fragments at random to be sure that the sync map is mostly correct and it just needs fine tuning. If not, check your aeneas input files and parameters and run aeneas again.

2. To check the begin time of each fragment, click on the corresponding text or timestamp. If necessary, use the + and − buttons to adjust it.

3. When done, you can save the adjusted sync map to file. If the desired format is not available, choose JSON and then use the aeneas.tools.convert_syncmap tool to convert it.

4. To start working, select your audio and JSON files:

Audio file:
JSON file:
ıı

Time increment (s): Show ID:
Text alignment:

Playback rate: Continuous play:
Time format:
Transition offset (s):

Format: